<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/revisions?lang_cible=ast
// ** ne pas modifier le fichier **

return [

	// D
	'diff_para_ajoute' => 'Párrafu amestau',
	'diff_para_deplace' => 'Párrafu movíu',
	'diff_para_supprime' => 'Párrafu desaniciau',
	'diff_texte_ajoute' => 'Testu amestau',
	'diff_texte_deplace' => 'Testu movíu',
	'diff_texte_supprime' => 'Testu desaniciau',

	// I
	'info_historique' => 'Revisiones:',
	'info_historique_lien' => 'Amosar l’históricu de los cambéos',
	'info_historique_titre' => 'Siguimientu de les revisiones',

	// V
	'version_deplace_rubrique' => 'Desasitiáo de <b>« @from@ »</b> pa <b>« @to@ »</b>.',
	'version_initiale' => 'Versión d’entamu',
];
